@@ -1,13 +1,13 @@
 use std::ffi::c_void;
 
-use crate::{bindings::MonoThread, void_ptr::MonoVoidPtr};
+use crate::{bindings::MonoThread, AsRawVoid};
 
 struct Thread {
     pub mono_thread: *mut MonoThread,
 }
 
-impl MonoVoidPtr for Thread {
-    fn as_void_ptr(self) -> *mut c_void {
+impl AsRawVoid for Thread {
+    fn as_raw_void(self) -> *mut c_void {
         self.mono_thread as *mut c_void
     }
 }
